Boot image management for OCI containers.
A bootable EROFS image is a derived artifact from an OCI container image that filters out some components (such as the UKI) to avoid circular references.
Functions
- boot_
image - Returns the boot EROFS image verity, if one exists.
- remove_
boot_ image - Remove the bootable EROFS image reference (idempotent).