pub enum BootImageMatch<ObjectID> {
Found {
mode: XattrFiltering,
version: FormatVersion,
digest: ObjectID,
},
NotFound(usize),
}Expand description
Result of [find_matching_boot_image].
Variants
Found
A (mode, format version) combination produced the expected digest.
Fields

mode: XattrFilteringThe xattr filtering mode that produced digest.

version: FormatVersionThe EROFS format version that produced digest.

digest: ObjectIDThe resulting boot image digest, equal to the expected
argument passed to [find_matching_boot_image].
NotFound(usize)
No combination matched. Contains the number of (mode, version) combinations that were tried, for use in error messages.