pull

Function pull 

pub async fn pull<ObjectID: FsVerityHashValue>(
    repo: &Arc<Repository<ObjectID>>,
    imgref: &str,
    reference: Option<&str>,
    opts: PullOptions<'_>,
) -> Result<PullResult<ObjectID>>
Pull the target image, and add the provided tag. If this is a mountable image (i.e. not an artifact), it is not unpacked by default.

When the containers-storage feature is enabled, the image reference starts with containers-storage:, and PullOptions::local_fetch is not LocalFetchOpt::Disabled, this uses the native cstor import path which supports zero-copy reflinks/hardlinks. Otherwise, it uses skopeo.

See PullOptions for tunable knobs (local-copy mode, extra storage roots, image proxy configuration).