pub struct ImageInfo {
pub name: String,
pub manifest_digest: Digest,
pub is_container: bool,
pub architecture: String,
pub os: String,
pub created: Option<String>,
pub layer_count: usize,
pub referrer_count: usize,
}Expand description
Summary information about a stored OCI image. FIXME change this to just have a struct of manifest+config JSON plus a few helper methods. We shouldn’t be re-parsing created timestamp here callers should directly access that etc
Fields
name: StringThe tag/name of the image
manifest_digest: DigestThe manifest digest
is_container: boolWhether this is a container image (vs artifact)
architecture: StringArchitecture (empty for artifacts)
os: StringOS (empty for artifacts)
created: Option<String>Creation timestamp
layer_count: usizeNumber of layers/blobs
referrer_count: usizeNumber of OCI referrers (signatures, attestations, etc.)