#[non_exhaustive]pub enum ProgressEvent {
Started {
id: ComponentId,
total: Option<u64>,
unit: ProgressUnit,
},
Progress {
id: ComponentId,
fetched: u64,
total: Option<u64>,
},
Skipped {
id: ComponentId,
},
Done {
id: ComponentId,
transferred: u64,
},
Message(String),
}Expand description
Events emitted during a pull or download operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Started
A new component (layer/object) has started being fetched.
Fields

id: ComponentIdIdentifier for this component.

unit: ProgressUnitUnit of measurement for total and subsequent Progress events.
Progress
Progress update for a component.
Fields

id: ComponentIdIdentifier for this component.
Skipped
A component was skipped because it was already present.
This event may be emitted without a preceding ProgressEvent::Started
when the component is determined to be cached before any download begins.
Renderers must handle this case gracefully.
Fields

id: ComponentIdIdentifier for the skipped component.
Done
A component completed successfully.
Fields

id: ComponentIdIdentifier for this component.
Message(String)
A human-readable status message (replaces progress-bar text lines).