Module boot

Module boot 

Boot image management for OCI containers.

A bootable EROFS image is a derived artifact from an OCI container image that filters out some components (such as the UKI) to avoid circular references.

Functions

boot_image
Returns the boot EROFS image verity, if one exists.
remove_boot_image
Remove the bootable EROFS image reference (idempotent).